@@ -10,6 +10,7 @@ pub mod effects {
         Magenta,
         Cyan,
         White,
+        RGB(u8, u8, u8),
     }
 
     /// enum to represent special printings other than colors
@@ -51,6 +52,7 @@ pub mod print {
             Color::Magenta => String::from("\x1b[35m"),
             Color::Cyan => String::from("\x1b[36m"),
             Color::White => String::from("\x1b[37m"),
+            Color::RGB(r, g, b) => format!("\x1b[38;2;{};{};{}m", r, g, b),
         }
     }
 
@@ -78,6 +80,7 @@ pub mod print {
             Color::Magenta => String::from("\x1b[45m"),
             Color::Cyan => String::from("\x1b[46m"),
             Color::White => String::from("\x1b[47m"),
+            Color::RGB(r, g, b) => format!("\x1b[48;2;{};{};{}m", r, g, b),
         }
     }
 
