@@ -4,10 +4,13 @@
 //! with btui you can create beautiful text user interfaces for the terminal.
 //! To get started add `btui` as a dependency to your project:
 //! ```toml
-//! btui = "0.3.2"
+//! btui = "0.4.4"
 //! ```
 
+#[cfg(feature = "core")]
 mod ft;
+#[cfg(feature = "linux")]
+pub mod linux;
 pub use ft::{effects, print};
 
 #[cfg(test)]
